.. goscalecms documentation master file, created by
   sphinx-quickstart on Tue May  8 12:39:57 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

GoScale CMS documentation
=========================

`GoScale CMS`_ is an extension of `Django CMS`_.

.. _`GoScale CMS`: http://www.goscalecms.com
.. _`Django CMS`: http://django-cms.org


It's a set of unique plugins and useful tools for Django CMS that makes it very powerful by seamlessly integrating content from 3rd party websites like:

* Blogger_ and Tumblr_
* Youtube_ and Vimeo_
* Picasa_ and `Google+`_
* `Google Calendar`_ and Forms_
* Any RSS/Atom feeds

.. _Blogger: http://blogger.com
.. _Tumblr: http://tumblr.com
.. _Youtube: http://youtube.com
.. _Vimeo: http://vimeo.com
.. _Picasa: http://picasaweb.google.com
.. _`Google+`: http://plus.google.com
.. _`Google Calendar`: http://google.com/calendar
.. _Forms: http://google.com/drive

But it's more than just content. GoScale plugins add some fancy functionality to make this content shine!

It's perfect for quickly building Mashups and Media heavy sites.

Website: http://goscalecms.com

GitHub repository: https://github.com/sternoru/goscalecms

Google Group: https://groups.google.com/forum/?fromgroups#!forum/goscale-cms

Credits
-------

* This is a set of tools and plugins for `Django CMS <http://django-cms.org>`_
* Product of `Sterno.Ru <http://sterno.ru/en/>`_.
* Developed and maintained under supervision of `Evgeny Demchenko <https://github.com/littlepea>`_

Developed with
^^^^^^^^^^^^^^

.. image:: http://www.jetbrains.com/img/logos/pycharm_logo.gif
    :width: 185 px

Installation
---------------

.. toctree::
   :maxdepth: 2

   installation.rst

Usage
---------------

.. toctree::
   :maxdepth: 2

   plugins.rst
   settings.rst
   management.rst
   celery.rst

Advanced
---------------

.. toctree::
   :maxdepth: 2

   tags.rst
   plugins_frontend.rst
   themes.rst
   auth.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

